import os

from torch.utils.data import Dataset


class LineDataset(Dataset):

    def __init__(self, path: str, root: str | None = None, split: str = 'train'):
        """
        Line based dataset. Note that this dataset is expected to be used only for testing.

        Args:
            path (str): path to a textfile to build the dataset from.
            root (str | None): Not used.
            split (str): Split to be returned. Can be 'train', 'test' or
                'valid'.

        """
        super().__init__()

        assert split in ('train', 'test', 'valid'), \
            "Split must be 'train', 'test' or 'valid'! Aborting..."

        if os.path.isfile(path) is False:
            raise ValueError(f"{path} not found")

        with open(path, encoding="utf-8") as f:
            self.lines = [line for line in f.read().splitlines() if (len(line) > 0 and not line.isspace())]

    def __len__(self) -> int:
        """
        Return the length of the dataset, which is the total number of lines
        contained in the text file passed as an argument.
        """
        return len(self.lines)

    def __getitem__(self, idx: int) -> str:
        """
        Return the article indexed by idx.

        Args:
            idx (int): The index of the article in the dataset.

        """
        return self.lines[idx]